Function rustc_trans::session::config::optgroupsUnstable
[-] [+]
[src]
pub fn optgroups() -> Vec<OptGroup>
Returns all of the stable rustc command line options.
pub fn optgroups() -> Vec<OptGroup>
Returns all of the stable rustc command line options.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).